var examples =
[
    [ "Surface_mesh_segmentation/sdf_values_example.cpp", "Surface_mesh_segmentation_2sdf_values_example_8cpp-example.html", null ],
    [ "Surface_mesh_segmentation/segmentation_from_sdf_values_example.cpp", "Surface_mesh_segmentation_2segmentation_from_sdf_values_example_8cpp-example.html", null ],
    [ "Surface_mesh_segmentation/segmentation_from_sdf_values_SM_example.cpp", "Surface_mesh_segmentation_2segmentation_from_sdf_values_SM_example_8cpp-example.html", null ],
    [ "Surface_mesh_segmentation/segmentation_via_sdf_values_example.cpp", "Surface_mesh_segmentation_2segmentation_via_sdf_values_example_8cpp-example.html", null ],
    [ "Surface_mesh_segmentation/segmentation_with_facet_ids_example.cpp", "Surface_mesh_segmentation_2segmentation_with_facet_ids_example_8cpp-example.html", null ],
    [ "Surface_mesh_segmentation/extract_segmentation_into_mesh_example.cpp", "Surface_mesh_segmentation_2extract_segmentation_into_mesh_example_8cpp-example.html", null ]
];